@@ -116,21 +116,12 @@ class Kraken_html:
 
 
 
-    def page(self):
+    def page(self, content = ''):
 
         
-        content = ''
         
         html_nav = self.navbar('Test title', self.nav)
 
-        if self.input_record:
-            content += self.record(self.input_record)
-
-        if self.input_records:    
-            content += self.table(self.input_records)
-
-
-        html_nav = self.navbar('Test title', self.nav)
 
         content = self.bootstrap(html_nav, self.title_nav, content)
 
